@@ -300,14 +300,13 @@ cartesian2dGrob <- function(widget, interiorPlotGrob = NULL, name = NULL, gp = N
                            )
     )
   }
-
+  # loon.pretty is still in development
   axis <- loon.pretty(widget)
   xaxis.major <- axis$xaxis.major
-  xaxis.minor <- axis$xaxis.minor
   yaxis.major <- axis$yaxis.major
+  xaxis.minor <- axis$xaxis.minor
   yaxis.minor <- axis$yaxis.minor
 
-
   titleGrob <- condGrob(test =  showLabels & (title != ""),
                         grobFun = textGrob,
                         name = "title",
@@ -927,26 +926,6 @@ glyph_to_pch <- function(glyph) {
 
 }
 
-
-# see optionDatabase.tcl
-as_r_point_size <- function(size) {
-
-  if (is.numeric(size)) {
-    # trial and error to choose scale for size
-    size <- sqrt(size / 12)
-    size[size < 0.1] <- 0.1
-  }
-  size
-}
-
-as_r_text_size <- function(size){
-  if (is.numeric(size)) {
-    # trial and error to choose scale for size
-    size <- 1 + 1.2 * (1 + size)^0.88
-  }
-  size
-}
-
 pixels_2_lines <- function(x) {
   x / 20
 }
@@ -1243,55 +1222,67 @@ loon.pretty <- function(widget, digits = 3) {
   zoomX <- widget['zoomX']
   zoomY <- widget['zoomY']
 
+
   if(swap) {
-    tcl("set", "xfrom", panY)
-    tcl("set", "yfrom", panX)
-    tcl("set", "xto", panY + deltaY/zoomY)
-    tcl("set", "yto", panX + deltaX/zoomX)
+    xrange <- c(panY, panY + deltaY/zoomY)
+    yrange <- c(panX, panX + deltaX/zoomX)
   } else {
-    tcl("set", "xfrom", panX)
-    tcl("set", "yfrom", panY)
-    tcl("set", "xto", panX + deltaX/zoomX)
-    tcl("set", "yto", panY + deltaY/zoomY)
+    yrange <- c(panY, panY + deltaY/zoomY)
+    xrange <- c(panX, panX + deltaX/zoomX)
   }
 
-  # set the number of axes
-  density <- as.numeric(.Tcl('set density $::loon::Options(ticks_density)'))
-  canvasWidth <- as.numeric(tkwinfo("width",widget))
-  canvasHeight <- as.numeric(tkwinfo("height",widget))
+  xaxis <- grid.pretty(xrange)
+  yaxis <- grid.pretty(yrange)
 
-  # margins
-  minimumMargins <- widget['minimumMargins']
-  margins <- c(0, 0, 0, 0)
-  if (showLabels) {
-    labelMargins <- widget['labelMargins']
-    if(xlabel == "") labelMargins[1] <- minimumMargins[1]
-    if(ylabel == "") labelMargins[2] <- minimumMargins[2]
-    if(title == "") labelMargins[3] <- minimumMargins[3]
-    margins <- margins + labelMargins
-  }
-  if (showScales) {margins <- margins + widget['scalesMargins'] }
-  if(showLabels | showScales) {
-    margins <- apply(cbind(margins, minimumMargins), 1, max)
-  }
-
-  plotWidth <- canvasWidth - (margins[2] + margins[4])
-  plotHeight <- canvasHeight - (margins[1] + margins[3])
-
-  if(plotWidth < 0) plotWidth <- 0
-  if(plotHeight < 0) plotHeight <- 0
-
-  tcl("set", "m_x", floor(plotWidth/100 * density))
-  tcl("set", "m_y", floor(plotHeight/100 * density))
-
-  xaxis <- round(
-    as.numeric(.Tcl('set xaxis [::loon::scales::extended $xfrom $xto [expr {2*$m_x}]]')),
-    digits = digits
-  )
-  yaxis <- round(
-    as.numeric(.Tcl('set yaxis [::loon::scales::extended $yfrom $yto [expr {2*$m_y}]]')),
-    digits = digits
-  )
+  # if(swap) {
+  #   tcl("set", "xfrom", panY)
+  #   tcl("set", "yfrom", panX)
+  #   tcl("set", "xto", panY + deltaY/zoomY)
+  #   tcl("set", "yto", panX + deltaX/zoomX)
+  # } else {
+  #   tcl("set", "xfrom", panX)
+  #   tcl("set", "yfrom", panY)
+  #   tcl("set", "xto", panX + deltaX/zoomX)
+  #   tcl("set", "yto", panY + deltaY/zoomY)
+  # }
+  #
+  # # set the number of axes
+  # density <- as.numeric(.Tcl('set density $::loon::Options(ticks_density)'))
+  # canvasWidth <- as.numeric(tkwinfo("width", widget))
+  # canvasHeight <- as.numeric(tkwinfo("height", widget))
+  #
+  # # margins
+  # minimumMargins <- widget['minimumMargins']
+  # margins <- c(0, 0, 0, 0)
+  # if (showLabels) {
+  #   labelMargins <- widget['labelMargins']
+  #   if(xlabel == "") labelMargins[1] <- minimumMargins[1]
+  #   if(ylabel == "") labelMargins[2] <- minimumMargins[2]
+  #   if(title == "") labelMargins[3] <- minimumMargins[3]
+  #   margins <- margins + labelMargins
+  # }
+  # if (showScales) {margins <- margins + widget['scalesMargins'] }
+  # if(showLabels | showScales) {
+  #   margins <- apply(cbind(margins, minimumMargins), 1, max)
+  # }
+  #
+  # plotWidth <- canvasWidth - (margins[2] + margins[4])
+  # plotHeight <- canvasHeight - (margins[1] + margins[3])
+  #
+  # if(plotWidth < 0) plotWidth <- 0
+  # if(plotHeight < 0) plotHeight <- 0
+  #
+  # tcl("set", "m_x", floor(plotWidth/100 * density))
+  # tcl("set", "m_y", floor(plotHeight/100 * density))
+  #
+  # xaxis <- round(
+  #   as.numeric(.Tcl('set xaxis [::loon::scales::extended $xfrom $xto [expr {2*$m_x}]]')),
+  #   digits = digits
+  # )
+  # yaxis <- round(
+  #   as.numeric(.Tcl('set yaxis [::loon::scales::extended $yfrom $yto [expr {2*$m_y}]]')),
+  #   digits = digits
+  # )
 
   is.even <- function(x) !as.logical(x %% 2)
 
